哈尔的移动城堡 (豆瓣)
Description: 哈尔的移动城堡电影简介和剧情介绍,哈尔的移动城堡影评、图片、预告片、影讯、论坛、在线购票
Keywords: 哈尔的移动城堡,ハウルの動く城,哈尔的移动城堡影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.40豆瓣电影Top250

# 哈尔的移动城堡 ハウルの動く城 (2004)

导演: 宫崎骏
编剧: 宫崎骏 / 黛安娜·温恩·琼斯
主演: 倍赏千惠子 / 木村拓哉 / 美轮明宏 / 我修院达也 / 神木隆之介 / 伊崎充则 / 大泉洋 / 大塚明夫 / 原田大二郎 / 加藤治子 / 都筑香弥子
类型: 动画 / 奇幻 / 冒险
制片国家/地区: 日本
语言: 日语
上映日期: 2004-09-05(威尼斯电影节) / 2004-11-20(日本)
片长: 119分钟
又名: 哈尔移动城堡(港) / 霍尔的移动城堡(台) / 呼啸山城 / 豪尔的机动城堡 / Howl's Moving Castle / Hauru no ugoku shiro
IMDb: tt0347149
豆瓣评分
引用
9.1
962366人评价
5星
63.5%
4星
29.7%
3星
6.3%
2星
0.4%
1星
0.1%
好于 98% 动画片
好于 98% 奇幻片
想看 看过
评价:
推荐

## 哈尔的移动城堡的剧情简介 · · · · · ·

继母因无力负担生活，将苏菲和她的两个妹妹都送到了制帽店去当学徒。两个妹妹很快先后就离开了制帽店去追寻各自的梦想，只有苏菲坚持了下来。一天，小镇旁边来了一座移动堡垒，传说堡垒的主人哈尔专吸取年青姑娘的灵魂，所以小镇的姑娘都不敢靠近。
一个恶毒的巫婆为了报复苏菲与哈尔见面，用巫术把她变成了一个80岁的老太婆，而且苏菲还不能对别人说出自己身中的巫术。无奈，苏菲决定独自一人逃离小镇。天黑了，虚弱的苏菲没走多远，来到了移动城堡。心想自己已经是老太婆了，苏菲壮着胆子走进了城堡。不想，遇到了和她遭遇相同的火焰魔。两人约定彼此帮助对方打破各自的咒语…… ©豆瓣

## 哈尔的移动城堡的演职员 · · · · · · ( 全部 49 )

- 宫崎骏 导演
- 倍赏千惠子 配 苏菲 ソフィー Sofî
- 木村拓哉 配 哈尔 ハウル Hauru
- 美轮明宏 配 荒野女巫 荒地の魔女 Arechi no Majo
- 我修院达也 配 卡西法 カルシファー Karushifâ
- 神木隆之介 配 马鲁克 マルクル Marukuru

## 哈尔的移动城堡的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1846 · 添加 )

## 哈尔的移动城堡的获奖情况 · · · · · · ( 全部 )

- 第78届奥斯卡金像奖
- 最佳动画长片(提名)
- 宫崎骏

- 第61届威尼斯电影节
- 主竞赛单元 金狮奖 (提名)
- 宫崎骏

- 第25届香港电影金像奖
- 最佳亚洲电影(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  幽灵公主

  风之谷

  魔女宅急便

  大闹天宫

  红猪

  猫的报恩

  崖上的波妞

  侧耳倾听

  龙猫

我要写短评

## 哈尔的移动城堡的短评 · · · · · · ( 全部 172694 条 )

热门 / 最新 / 好友

### 10471 有用 一粒煞白 看过 2010-05-30 20:39:40

目前为止觉得哈尔是宫崎骏作品里最帅的男角

### 6448 有用 2ya 看过 2006-01-18 12:01:31

看了这个电影就想要一个家。擦地板，在阳光下面放上铺着干净桌布的餐桌，还有照顾小火苗，就如同守护爱人的心一般。

### 6187 有用 小耳朵图吗 看过 2007-08-17 19:11:24

宫崎骏的片子里。老奶奶都很丑。但都是好老奶奶。

### 4404 有用 伍德与夏洛蒂 看过 2011-03-16 20:55:33

虽然它确实不如宫崎骏的很多作品，也不是最受欢迎的，但却是我最爱。每次响起俩人初遇时在屋顶跳跃的那段音乐，都觉得莫名的悲伤。也正是因为这种感觉，它才是最爱。

### 3495 有用 A L E X 看过 2017-01-01 22:38:17

染发剂事件之后，形象崩塌暴露屁孩本质萌到吐血！哈尔一定是宫崎骏作品最帅男主了，配音还是木 村 拓 哉，简直不给活路

> 更多短评 172694条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 哈尔的移动城堡的影评 · · · · · · ( 全部 1683 条 )

热门 / 最新 / 好友
音娃 2008-08-02 19:54:55

## 宫崎骏《哈尔的移动城堡》剧情疑难解答

q1" 为什么人们传说霍尔会吃掉年轻女孩子的心脏？ a1" 在电影中没有提到，但根据原著 魔幻城堡(黛安娜 韦恩 琼斯着尖端出版社出版)描述，霍尔自从跟火魔卡西法订下契约，交出心脏之后，他再也无法真心爱人，但他仍旧不放弃寻求真爱，只是一旦追求的对象爱上他，他的感情也就结... (展开)
14498 138 695回应 收起
Distancer 2009-01-21 22:25:15

## 宫崎骏的心灵诗篇（转载）

《霍尔的移动城堡》是迄今为止宫崎骏最深刻的作品。这部动画片情节跳跃，隐喻铺天盖地，和宫崎骏以往绵密、通俗的叙事风格截然不同。一部分观众表示剧情难以理解——这就是我写作此文的目的。我认为这是一部伟大的电影，我要把我的心得写下来，与所有热爱宫崎骏、以及胸中仍有... (展开)
7779 187 560回应 收起
viyu 2005-12-03 03:22:42

## 哈尔的移动城堡

宫崎峻一生只拍了一部电影，名字叫做我们的纯真与失落。 当我们无知但无畏地望着这个世界的时候，我们的眼睛是闪亮的，好像一望无际的水面。纯真失落在成长的迷途中，失落在与魔鬼交换POWER的协议里，失落在喧嚣的繁华以及冷漠的假面背后。 哈尔的移动城堡，是还没飞上天空的... (展开)
1961 83 209回应 收起
呱啦啦 2006-06-05 11:08:32

## 《豪尔的移动城堡》动画与原作对比

在欲火焚心却坚持不去看枪版和小说的状态下等了快一年以后……终于出现了～～正正经经的DVD啊！中文字幕啊！ 特地抽出一天时间一口气看完动画＋中文小说＋英文小说后，按奈不住写下这篇东西发泄一下～！ 更为详细的解析就去看《24格》吧，这个仅仅是个人的一些见解... (展开)
1392 65 164回应 收起
越简单越幸福 2006-04-11 17:00:09

## 爱情＋勇气＝魔法

《哈尔的移动城堡》表达了一个朴素的主题：勇气和爱。 在经历了《风之谷》《幽灵公主》等一系列反战，保护自然的主题后，宫崎骏要表达的东西更为本质，那就是：对爱的追求。 1、一见钟情与慢慢的爱 很明显，苏菲对哈尔一见钟情：从哈尔搭她的肩为她解围开始，到拉着她在空中... (展开)
859 31 107回应 收起
ad自耕农 2006-05-09 12:12:51

## 最后的距离

http://blog.sina.com.cn/m/adking 晚上，看完了《哈尔的移动城堡》，感动。 我想：日本是一个多么贪婪无耻的国家，它们已经拥有了黑泽明，却还拥有了——宫崎峻。 这个世界上，没有多少导演，还在坚持做二维动画片。而其中，只有一个导演，不但坚持着手工绘画，还坚持使用... (展开)
417 32 100回应 收起
安文生 2009-09-27 18:20:51

## 苏菲和稻草人

重温《哈尔的移动城堡》。每个角色都光彩照人。这次，留心到了那个易被人忽略的稻草人。 他只是默默守护着苏菲。在她为哈尔生了气，在外淋雨哭泣时，出现在她身边的定是稻草人。会带着伞，为她撑起一片晴空，静静的陪伴着她。在她晒衣服时，他欢快的化为一根晾杆，分享着她的平... (展开)
388 13 49回应 收起
欢乐海鹦乌娜 2018-02-04 15:44:00

## 浪漫动人的魔法爱情故事，宫崎骏爷爷的经典心灵颂歌！

这篇影评可能有剧透

看魔法公主的时候看到推荐的同类型作品点进去看的，很好看，真的，一贯的宫崎骏老爷爷的画风和温暖风格。 老爷爷的作品音乐都很棒，出了很多经典配乐，这部电影也不例外，好听的！ 这是一部满满英伦风格的动漫电影，英伦小镇，中世纪的帽子服装等不要太棒！还有那美美的荷兰风... (展开)
168 5 31回应 收起
工藤新一的猴子 2017-04-12 14:22:06

## 《哈尔的移动城堡》观后有感！

《哈尔的移动城堡》是迄今为止宫崎骏最深刻的作品。这部动画片情节跳跃，隐喻铺天盖地，和宫崎骏以往绵密、通俗的叙事风格截然不同。 本片的两个主角，其人性因素相当饱满，远超过以往动画片任何角色。苏菲是个文静善良的小姑娘，她对哈尔一见倾心，但是她自认为不漂亮，不敢奢... (展开)
188 8 8回应 收起
克里虾 2018-08-11 16:43:21

## 换个角度，这是一个关于抑郁症的故事

这篇影评可能有剧透

之前已经有很多读者提出JK Rowling在哈利波特里描写的摄魂怪与抑郁症的隐喻："The metaphor is not lost on fans, with many deeply relating to the trials and emotions found with their own depression reflected in Dementors."[1] "A depression that makes you feel col... (展开)
175 1 16回应 收起

> 更多影评 1683篇

添加新讨论

## 讨论区 · · · · · ·

那个app可以看哈尔的移动城堡 | 来自豆友217914010 | 9 回应 | 2022-11-24 09:33:54
原著里是哈尔当了电影开头那两个士兵的角色吗？！ | 来自仓木麻衣 | 8 回应 | 2022-11-23 05:58:17
为什么苏菲把火浇灭了，哈尔没事？ | 来自大份烤冷面 | 8 回应 | 2022-11-19 09:17:36
宫崎骏的作品总是评分畸高 | 来自青瑾 | 111 回应 | 2022-11-16 21:44:19
嘎 | 来自howcanone |  | 2022-11-11 07:16:02

> 去这部影片的讨论区（全部415条）

## 关于《哈尔的移动城堡》的问题 · · · · · · ( 全部22个 )

- 女主再次碰到女巫时为何是一种朋友间闹了小矛盾的气氛呢？ 4人回答
- 苏菲的咒语是什么时候解除的？为什么苏菲总是在老人跟年轻人间转换？ 5人回答

> 全部22个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- Victor
  刚刚 看过
- momo
  4分钟前 看过
- 沉默是最好的
  8分钟前 看过

1841784人看过 / 258510人想看

订阅哈尔的移动城堡的评论:
feed: rss 2.0